==> xoonips-3.49.tar.gz: xoonips-3.49/xoonips/advanced_search_itemselect_transfer.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

require 'include/common.inc.php';

require 'include/AL.php';
require 'include/lib.php';

$xoopsOption['template_main'] = 'xoonips_advanced_search_itemselect_transfer.html';

// disable to link index tree
$xoonipsURL = '';

require XOOPS_ROOT_PATH.'/header.php';

require_once 'include/extra_param.inc.php';
$formdata = &xoonips_getutility('formdata');
$textutil = &xoonips_getutility('text');
$xoopsTpl->assign('extra_param', $textutil->html_special_chars(serialize(xoonips_extra_param_restore())));
$xoopsTpl->assign('submit_url', $formdata->getValue('post', 'submit_url', 's', false));
$xoopsTpl->assign('selected_original', $formdata->getValueArray('post', 'selected_original', 'i', false));
require 'include/advanced_search.inc.php';

require XOOPS_ROOT_PATH.'/footer.php';

==> xoonips-3.50.tar.gz: xoonips-3.50/xoonips/advanced_search_itemselect_transfer.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

require 'include/common.inc.php';

require 'include/AL.php';
require 'include/lib.php';

$xoopsOption['template_main'] = 'xoonips_advanced_search_itemselect_transfer.html';

// disable to link index tree
$xoonipsURL = '';

require XOOPS_ROOT_PATH.'/header.php';

require_once 'include/extra_param.inc.php';
$formdata = &xoonips_getutility('formdata');
$textutil = &xoonips_getutility('text');
$xoopsTpl->assign('extra_param', $textutil->html_special_chars(json_encode(xoonips_extra_param_restore())));
$xoopsTpl->assign('submit_url', $formdata->getValue('post', 'submit_url', 's', false));
$xoopsTpl->assign('selected_original', $formdata->getValueArray('post', 'selected_original', 'i', false));
require 'include/advanced_search.inc.php';

require XOOPS_ROOT_PATH.'/footer.php';
